@@ -33,6 +33,7 @@
 # /usr/share/common-licenses/AGPL-3; if not, see
 # <https://www.gnu.org/licenses/>.
 
+import logging
 import random
 import re
 from functools import wraps
@@ -43,7 +44,7 @@ import ldap.schema
 import six
 from ldapurl import LDAPUrl, isLDAPUrl
 
-import univention.debug
+import univention.logging  # noqa: F401
 from univention.config_registry import ConfigRegistry
 
 
@@ -52,6 +53,8 @@ try:
 except ImportError:
     pass
 
+log = logging.getLogger('LDAP')
+
 
 def parentDn(dn, base=''):
     # type: (str, str) -> Optional[str]
@@ -284,7 +287,7 @@ class access(object):
         try:
             client_retry_count = int(ucr.get('ldap/client/retry/count', 10))
         except ValueError:
-            univention.debug.debug(univention.debug.LDAP, univention.debug.ERROR, "Unable to read ldap/client/retry/count, please reset to an integer value")
+            log.error("Unable to read ldap/client/retry/count, please reset to an integer value")
             client_retry_count = 10
 
         self.client_connection_attempt = client_retry_count + 1
@@ -302,7 +305,7 @@ class access(object):
         """
         self.binddn = binddn
         self.bindpw = bindpw
-        univention.debug.debug(univention.debug.LDAP, univention.debug.ALL, 'bind binddn=%s' % self.binddn)
+        log.debug('bind binddn=%s', self.binddn)
         self.lo.simple_bind_s(self.binddn, self.bindpw)
 
     @_fix_reconnect_handling
@@ -321,7 +324,7 @@ class access(object):
         }, 'SAML')
         self.lo.sasl_interactive_bind_s('', saml)
         self.binddn = self.whoami()
-        univention.debug.debug(univention.debug.LDAP, univention.debug.ALL, 'SAML bind binddn=%s' % self.binddn)
+        log.debug('SAML bind binddn=%s', self.binddn)
 
     @_fix_reconnect_handling
     def bind_oauthbearer(self, authzid, bindpw):
@@ -344,7 +347,7 @@ class access(object):
         }, 'OAUTHBEARER')
         self.lo.sasl_interactive_bind_s('', oauth)
         self.binddn = self.whoami()
-        univention.debug.debug(univention.debug.LDAP, univention.debug.INFO, 'OAUTHBEARER bind binddn=%r' % self.binddn)
+        log.debug('OAUTHBEARER bind binddn=%r', self.binddn)
 
     def unbind(self):
         # type: () -> None
@@ -371,10 +374,10 @@ class access(object):
         # type: (Optional[str]) -> None
 
         if self.reconnect:
-            univention.debug.debug(univention.debug.LDAP, univention.debug.ALL, 'establishing new connection with retry_max=%d' % self. client_connection_attempt)
+            log.debug('establishing new connection with retry_max=%d', self.client_connection_attempt)
             self.lo = ldap.ldapobject.ReconnectLDAPObject(self.uri, trace_stack_limit=None, retry_max=self.client_connection_attempt, retry_delay=1)
         else:
-            univention.debug.debug(univention.debug.LDAP, univention.debug.ALL, 'establishing new connection')
+            log.debug('establishing new connection')
             self.lo = ldap.initialize(self.uri, trace_stack_limit=None)
 
         if ca_certfile:
@@ -386,7 +389,7 @@ class access(object):
                 try:
                     self.__starttls()
                 except Exception:
-                    univention.debug.debug(univention.debug.LDAP, univention.debug.WARN, 'Could not start TLS')
+                    log.warning('Could not start TLS')
             elif self.start_tls == 2:
                 self.__starttls()
 
@@ -523,8 +526,7 @@ class access(object):
         :raises ldap.NO_SUCH_OBJECT: Indicates the target object cannot be found.
         :raises ldap.INAPPROPRIATE_MATCHING: Indicates that the matching rule specified in the search filter does not match a rule defined for the attribute's syntax.
         """
-        univention.debug.debug(univention.debug.LDAP, univention.debug.ALL, 'uldap.search filter=%s base=%s scope=%s attr=%s unique=%d required=%d timeout=%d sizelimit=%d' % (
-            filter, base, scope, attr, unique, required, timeout, sizelimit))
+        log.debug('uldap.search filter=%s base=%s scope=%s attr=%s unique=%d required=%d timeout=%d sizelimit=%d', filter, base, scope, attr, unique, required, timeout, sizelimit)
 
         if not base:
             base = self.base
@@ -710,7 +712,7 @@ class access(object):
         if not serverctrls:
             serverctrls = []
 
-        univention.debug.debug(univention.debug.LDAP, univention.debug.ALL, 'uldap.add dn=%s' % dn)
+        log.debug('uldap.add dn=%s', dn)
         nal = {}  # type: Dict[str, Any]
         for i in al:
             key, val = i[0], i[-1]
@@ -748,7 +750,7 @@ class access(object):
         :returns: The distinguished name.
         :rtype: str
         """
-        univention.debug.debug(univention.debug.LDAP, univention.debug.ALL, 'uldap.modify %s' % dn)
+        log.debug('uldap.modify %s', dn)
 
         if not serverctrls:
             serverctrls = []
@@ -781,7 +783,7 @@ class access(object):
         if not self.compare_dn(dn, new_dn):
             if rename_callback:
                 rename_callback(dn, new_dn, ml)
-            univention.debug.debug(univention.debug.LDAP, univention.debug.WARN, 'rename %s' % (new_rdn,))
+            log.warning('rename %s', new_rdn)
             self.rename_ext_s(dn, new_rdn, serverctrls=serverctrls, response=response)
             dn = new_dn
         if ml:
@@ -865,7 +867,7 @@ class access(object):
         :type serverctrls: list[ldap.controls.LDAPControl]
         :param dict response: An optional dictionary to receive the server controls of the result.
         """
-        univention.debug.debug(univention.debug.LDAP, univention.debug.ALL, 'uldap.rename %s -> %s' % (dn, newdn))
+        log.debug('uldap.rename %s -> %s', dn, newdn)
         oldsdn = self.parentDn(dn)
         newrdn = ldap.dn.dn2str([ldap.dn.str2dn(newdn)[0]])
         newsdn = ldap.dn.dn2str(ldap.dn.str2dn(newdn)[1:])
@@ -874,10 +876,10 @@ class access(object):
             serverctrls = []
 
         if oldsdn and newsdn.lower() == oldsdn.lower():
-            univention.debug.debug(univention.debug.LDAP, univention.debug.ALL, 'uldap.rename: modrdn %s to %s' % (dn, newrdn))
+            log.debug('uldap.rename: modrdn %s to %s', dn, newrdn)
             self.rename_ext_s(dn, newrdn, serverctrls=serverctrls, response=response)
         else:
-            univention.debug.debug(univention.debug.LDAP, univention.debug.ALL, 'uldap.rename: move %s to %s in %s' % (dn, newrdn, newsdn))
+            log.debug('uldap.rename: move %s to %s in %s', dn, newrdn, newsdn)
             self.rename_ext_s(dn, newrdn, newsdn, serverctrls=serverctrls, response=response)
 
     @_fix_reconnect_handling
@@ -915,9 +917,9 @@ class access(object):
 
         :param str dn: The distinguished name of the object to remove.
         """
-        univention.debug.debug(univention.debug.LDAP, univention.debug.ALL, 'uldap.delete %s' % dn)
+        log.debug('uldap.delete %s', dn)
         if dn:
-            univention.debug.debug(univention.debug.LDAP, univention.debug.ALL, 'delete')
+            log.debug('delete')
             try:
                 self.lo.delete_s(dn)
             except ldap.REFERRAL as exc:
@@ -1004,7 +1006,7 @@ class access(object):
         :returns: LDAP connection object for the referred LDAP server.
         :rtype: ldap.ldapobject.ReconnectLDAPObject
         """
-        univention.debug.debug(univention.debug.LDAP, univention.debug.INFO, 'Following LDAP referral')
+        log.debug('Following LDAP referral')
         exc = exception.args[0]
         info = exc.get('info')
         ldap_url = info[info.find('ldap'):]
@@ -1022,7 +1024,7 @@ class access(object):
                 try:
                     lo_ref.start_tls_s()
                 except Exception:
-                    univention.debug.debug(univention.debug.LDAP, univention.debug.WARN, 'Could not start TLS')
+                    log.warning('Could not start TLS')
             elif self.start_tls == 2:
                 lo_ref.start_tls_s()
 
